@@ -23,13 +23,13 @@
 
 #include <QMutex>
 #include <QFile>
+#include <QFileInfo>
 #include <QMimeDatabase>
 
 #include <KDirWatch>
 #include <KLocalizedString>
 #include <KFilterDev>
 
-#include "logFileReader.h"
 #include "logFileReaderPrivate.h"
 
 #include "logging.h"
@@ -79,13 +79,13 @@ void LocalLogFileReader::init()
     // Init current file position
     d->previousFilePosition = 0;
 
-    logDebug() << "Reading local file " << d->logFile.url().path();
+    logDebug() << "Reading local file " << d->logFile.url().toLocalFile();
 }
 
 void LocalLogFileReader::watchFile(bool enable)
 {
     Q_D(LocalLogFileReader);
-    QString filePath = d->logFile.url().path();
+    QString filePath = d->logFile.url().toLocalFile();
 
     if (enable == true) {
         logDebug() << "Monitoring file : " << filePath;
@@ -107,7 +107,7 @@ void LocalLogFileReader::watchFile(bool enable)
 QIODevice *LocalLogFileReader::open()
 {
     Q_D(LocalLogFileReader);
-    QString filePath = d->logFile.url().path();
+    const QString filePath = d->logFile.url().toLocalFile();
 
     if (d->logFile.url().isValid() == false) {
         QString message(i18n("This file is not valid. Please adjust it in the settings of KSystemLog."));
@@ -119,16 +119,15 @@ QIODevice *LocalLogFileReader::open()
     QString mimeType = db.mimeTypeForFile(filePath, QMimeDatabase::MatchContent).name();
 
     logDebug() << filePath << " : " << mimeType;
-    QIODevice *inputDevice;
+    QScopedPointer<QIODevice> inputDevice;
 
     // Try to see if this file exists
-    QFile *file = new QFile(filePath);
+    QFileInfo info(filePath);
     // If the file does not exist
-    if (!file->exists()) {
+    if (!info.exists()) {
         QString message(i18n("The file '%1' does not exist.", filePath));
         emit errorOccured(i18n("File Does Not Exist"), message);
         emit statusBarChanged(message);
-        delete file;
         return nullptr;
     }
 
@@ -136,14 +135,14 @@ QIODevice *LocalLogFileReader::open()
     if (mimeType == QLatin1String("text/plain") || mimeType == QLatin1String("application/octet-stream")) {
         logDebug() << "Using QFile input device";
 
-        inputDevice = file;
+        inputDevice.reset(new QFile(filePath));
     }
     // Compressed file : we use the KFilterDev helper
     else {
         logDebug() << "Using KFilterDev input device";
 
         // inputDevice = KFilterDev::deviceForFile(filePath, mimeType);
-        inputDevice = new KCompressionDevice(filePath, KFilterDev::compressionTypeForMimeType(mimeType));
+        inputDevice.reset(new KCompressionDevice(filePath, KFilterDev::compressionTypeForMimeType(mimeType)));
 
         if (inputDevice == nullptr) {
             QString message(i18n("Unable to uncompress the '%2' format of '%1'.", filePath, mimeType));
@@ -157,11 +156,10 @@ QIODevice *LocalLogFileReader::open()
         QString message(i18n("You do not have sufficient permissions to read '%1'.", filePath));
         emit errorOccured(i18n("Insufficient Permissions"), message);
         emit statusBarChanged(message);
-        delete inputDevice;
         return nullptr;
     }
 
-    return inputDevice;
+    return inputDevice.take();
 }
 
 void LocalLogFileReader::close(QIODevice *inputDevice)
@@ -187,7 +185,7 @@ QStringList LocalLogFileReader::readContent(QIODevice *inputDevice)
 
     // Get the size file for the next calculation
     d->previousFilePosition = inputDevice->size();
-    logDebug() << "New file position : " << d->previousFilePosition << " (" << d->logFile.url().path() << ")";
+    logDebug() << "New file position : " << d->previousFilePosition << " (" << d->logFile.url().toLocalFile() << ")";
 
     return rawBuffer;
 }
@@ -204,13 +202,13 @@ void LocalLogFileReader::logFileModified()
 
     QIODevice *inputDevice = open();
     if (inputDevice == nullptr) {
-        logCritical() << "Could not open file " << d->logFile.url().path();
+        logCritical() << "Could not open file " << d->logFile.url().toLocalFile();
         return;
     }
 
     // If there are new lines in the file, insert only them or this is the first time we read this file
     if (d->previousFilePosition != 0 && d->previousFilePosition <= inputDevice->size()) {
-        logDebug() << "Reading from position " << d->previousFilePosition << " (" << d->logFile.url().path()
+        logDebug() << "Reading from position " << d->previousFilePosition << " (" << d->logFile.url().toLocalFile()
                    << ")";
 
         if (inputDevice->isSequential()) {
