@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _POSTFIX_CONFIGURATION_WIDGET_H_
-#define _POSTFIX_CONFIGURATION_WIDGET_H_
+#ifndef POSTFIX_CONFIGURATION_WIDGET_H
+#define POSTFIX_CONFIGURATION_WIDGET_H
 
 #include "logModeConfigurationWidget.h"
 
@@ -48,8 +48,7 @@ public:
         : LogModeConfigurationWidget(i18n("Postfix Log"), QStringLiteral(POSTFIX_MODE_ICON),
                                      i18n("Postfix Log"))
     {
-        QVBoxLayout *layout = new QVBoxLayout();
-        this->setLayout(layout);
+        QVBoxLayout *layout = new QVBoxLayout(this);
 
         QString description = i18n("<p>These files will be analyzed to show the <b>Postfix Logs</b>.</p>");
 
@@ -60,9 +59,9 @@ public:
         layout->addWidget(fileList);
     }
 
-    virtual ~PostfixConfigurationWidget() {}
+    ~PostfixConfigurationWidget() override {}
 
-    bool isValid() const Q_DECL_OVERRIDE
+    bool isValid() const override
     {
         if (fileList->isEmpty() == false) {
             logDebug() << "Postfix configuration valid";
@@ -73,7 +72,7 @@ public:
         return false;
     }
 
-    void saveConfig() Q_DECL_OVERRIDE
+    void saveConfig() override
     {
         logDebug() << "Saving config from Postfix Options...";
 
@@ -84,7 +83,7 @@ public:
         configuration->setLogFilesLevels(fileList->levels());
     }
 
-    void readConfig() Q_DECL_OVERRIDE
+    void readConfig() override
     {
         PostfixConfiguration *configuration = Globals::instance()
                                                   .findLogMode(QStringLiteral(POSTFIX_LOG_MODE_ID))
@@ -95,7 +94,7 @@ public:
         fileList->addPaths(configuration->logFilesPaths(), configuration->logFilesLevels());
     }
 
-    void defaultConfig() Q_DECL_OVERRIDE
+    void defaultConfig() override
     {
         // TODO Find a way to read the configuration per default
         readConfig();
@@ -105,4 +104,4 @@ private:
     LogLevelFileList *fileList;
 };
 
-#endif // _POSTFIX_CONFIGURATION_WIDGET_H_
+#endif // _POSTFIX_CONFIGURATION_WIDGET_H
